View source: R/EDM_AppSweeps.R
| EmbedDimension | R Documentation |
EmbedDimension uses Simplex to evaluate
prediction accuracy as a function of embedding dimension.
EmbedDimension(dataFrame = NULL, columns, target, lib, pred, maxE = 10, Tp = 1,
tau = -1, exclusionRadius = 0, embedded = FALSE,
validLib = logical(0), noTime = FALSE, ignoreNan = TRUE,
numProcess = 4, pathIn = "./", dataFile = "", pathOut = "./",
predictFile = "", backend = "RANN",
parameterList = FALSE, showPlot = FALSE)
dataFrame |
A data.frame of input data. The first column must be a time
index or time values unless |
columns |
Column name(s) to build the embedding: character vector or space-separated string. |
target |
Target column name to predict. |
lib |
Library (training) index range as (start end) pairs. |
pred |
Prediction index range as (start end) pairs. |
maxE |
Largest embedding dimension to evaluate. |
Tp |
Forecast interval (prediction horizon). |
tau |
Embedding delay (negative selects past lags). |
exclusionRadius |
Temporal (Theiler) exclusion radius around each prediction point. |
embedded |
If |
validLib |
Logical vector marking admissible library rows (or length 0 for all). |
noTime |
If |
ignoreNan |
Remove rows with NaN in the embedding from the library and prediction sets. |
numProcess |
Number of worker processes for the parameter sweep or task grid. |
pathIn |
File path for input |
dataFile |
Input dataFile, .csv format. |
pathOut |
Output file path for |
predictFile |
Output file name, .csv format. |
backend |
Nearest-neighbour backend: |
parameterList |
Append named list of parameters/values to return. |
showPlot |
If |
A data.frame with columns E, rho.
data(TentMap)
E.rho = EmbedDimension( dataFrame = TentMap, lib = "1 100", pred = "201 500",
columns = "TentMap", target = "TentMap", showPlot = FALSE )
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.