View source: R/EDM_AppSweeps.R
| PredictNonlinear | R Documentation |
PredictNonlinear uses SMap to evaluate
prediction accuracy as a function of the state-space localization parameter
theta.
PredictNonlinear(dataFrame = NULL, columns, target, lib, pred, theta = NULL, E = NULL,
Tp = 1, knn = 0, tau = -1, exclusionRadius = 0,
embedded = FALSE, validLib = logical(0), noTime = FALSE,
ignoreNan = TRUE, numProcess = 4, backend = "RANN",
pathIn = "./", dataFile = "", pathOut = "./", predictFile = "",
parameterList = FALSE, showPlot = FALSE, verbose = FALSE)
dataFrame |
A data.frame of input data. The first column must be a time
index or time values unless |
columns |
Column name(s) to build the embedding: character vector or space-separated string. |
target |
Target column name to predict. |
lib |
Library (training) index range as (start end) pairs. |
pred |
Prediction index range as (start end) pairs. |
theta |
S-map localisation parameter ( |
E |
Embedding dimension. Required (no default); must be a positive integer unless |
Tp |
Forecast interval (prediction horizon). |
knn |
Number of nearest neighbours. |
tau |
Embedding delay (negative selects past lags). |
exclusionRadius |
Temporal (Theiler) exclusion radius around each prediction point. |
embedded |
If |
validLib |
Logical vector marking admissible library rows (or length 0 for all). |
noTime |
If |
ignoreNan |
Remove rows with NaN in the embedding from the library and prediction sets. |
numProcess |
Number of worker processes for the parameter sweep or task grid. |
backend |
Nearest-neighbour backend: |
pathIn |
File path for input |
dataFile |
Input dataFile, .csv format. |
pathOut |
Output file path for |
predictFile |
Output file name, .csv format. |
parameterList |
Append named list of parameters/values to return. |
showPlot |
If |
verbose |
Not used. |
A data.frame with columns Theta and rho.
data(TentMapNoise)
theta.rho = PredictNonlinear( dataFrame = TentMapNoise, E = 2,
lib = "1 100", pred = "201 500", columns = "TentMap",
target = "TentMap", showPlot = FALSE )
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.