TentMap: Time series for a tent map with mu = 2.

TentMapR Documentation

Time series for a tent map with mu = 2.

Description

First-differenced time series generated from the tent map recurrence relation with mu = 2.

Usage

TentMap

Format

Data frame with 999 rows and 2 columns

Time

time index.

TentMap

tent map values.


rEDM documentation built on Aug. 30, 2026, 9:07 a.m.