gmw: Generate Market Weights and Put them in a Tibble

Description Usage Arguments Value

View source: R/edm_fun.R

Description

Uses 'gen_mkt_weights' to create a tibble for storing the market weights.

Usage

1
gmw(crops, markets)

Arguments

crops

A character vector of crops.

markets

A character vector of consumer markets.

Value

Returns a tibble of the market weights. @export


jholderieath/rEDM documentation built on Sept. 28, 2018, 12:25 a.m.