Learn R Programming

rEDM (version 0.4.4)

rEDM-package: Applications of empirical dynamic modeling from time series.

Description

The rEDM package provides an interface from R to C++ compiled objects that use time delay embedding to perform state-space reconstruction and nonlinear forecasting.

Arguments