Rdocumentation
powered by
Learn R Programming
rEDM (version 0.4.4)
tentmap_del: Time series for a tent map with mu = 2.
Description
First-differenced time series generated from the tent map recurrence relation with mu = 2.
Arguments