Learn R Programming

rEDM (version 0.4.4)

test_nonlinearity: Randomization test for nonlinearity using S-maps and surrogate data

Description

test_nonlinearity tests for nonlinearity using S-maps by comparing improvements in forecast skill (delta rho and delta mae) between linear and nonlinear models with a null distribution from surrogate data.

Usage

test_nonlinearity(ts, method = "ebisuzaki", num_surr = 200, T_period = 1,
  E = 1, ...)

Arguments

ts
the original time series
method
which algorithm to use to generate surrogate data
num_surr
the number of null surrogates to generate
T_period
the period of seasonality for seasonal surrogates (ignored for other methods)
E
the embedding dimension for s_map
...
optional arguments to s_map

Value

  • A data.frame containing the following components: ll{ delta_rho the value of the delta rho statistic delta_mae the value of the delat mae statistic num_surr the size of the null distribution delta_rho_p_value the p-value for delta rho delta_mae_p_value the p-value for delta mae }