make_block generates a lagged block with the appropriate max_lag and
tau, while respecting lib (by inserting NANs, when trying to lag past lib
regions)
make_block(block, max_lag = 3, t = NULL, lib = NULL, tau = 1)a data.frame or matrix where each column is a time series
the total number of lags to include for each variable
the time index for the block
a 2-column matrix (or 2-element vector) where each row specifes the first and last *rows* of the time series to use for attractor reconstruction
the lag to use for time delay embedding
A data.frame with the lagged columns and a time column