Method "random_shuffle" creates surrogates by randomly permuting the values
of the original time series.Method "Ebisuzaki" creates surrogates by randomizing the phases of a Fourier
transform, preserving the power spectra of the null surrogates.
Method "seasonal" creates surrogates by computing a mean seasonal trend of
the specified period and shuffling the residuals.
See test_nonlinearity for context.